@@ -46,13 +46,6 @@ fi
 
 case "$switch" in
    "start"|"restart")
-     #
-     echo "$msg_delimiter_star_line"
-     echo $msg_now_continue_to_run_drblpush
-     echo $msg_this_might_take_several_minutes
-     echo -n $msg_press_enter_to_continue
-     read
-
      # start drbl live first, which will setup drbl environment
      echo "Checking if DRBL related sevices are started or not..."
      dhcpd_pid=`pidof dhcpd3`
@@ -60,9 +53,19 @@ case "$switch" in
      unfsd_pid=`pidof unfsd`
      nfsd_pid=`pidof nfsd`
      if [ -z "$dhcpd_pid" -o -z "$tftpd_pid" ] || [ -z "$unfsd_pid" -a -z "$nfsd_pid" ]; then
+       echo "$msg_delimiter_star_line"
+       echo "$msg_drbl_env_is_not_ready_now_config"
+       echo $msg_this_might_take_several_minutes
+       echo -n $msg_press_enter_to_continue
+       read
+       echo "$msg_delimiter_star_line"
        drbl-live.sh start
      fi
 
+     echo "$msg_delimiter_star_line"
+     echo "$msg_drbl_env_is_ready"
+     echo "$msg_delimiter_star_line"
+     sleep 1
      dcs clonezilla-start
      ;;
    "stop")
